@@ -49,14 +49,16 @@ def create_json(intermediate_participant_path, output_dir_path):
     return info_dict
 
 
-def execute(intermediate_participant_path, output_dir_path, rerun=False):
+def execute(intermediate_participant_path, output_dir_path):
 
     misc_folder_name = "misc"
     information_dict_name = "info.json"
     folder_path = os.path.join(output_dir_path, misc_folder_name)
     information_dict_path = os.path.join(folder_path, information_dict_name)
 
-    if rerun: # when the json needs to be updated
+    if not os.path.exists(information_dict_path): # when the json needs to be updated
+        if not os.path.exists(folder_path):
+            os.makedirs(folder_path)
         info_dict = create_json(intermediate_participant_path, output_dir_path)
     else:
         # Load existing json file
